
# ARADI and LLAMA implementations (2024)

Implementation of the NSA cryptography algorithm [ARADI and LLAMA](https://eprint.iacr.org/2024/1240), published on 2024-08-05.

To do update on 01/09/2024:
- Implement LLAMA
- Implement methods to encrypt and decrypt files using ARADI.
- Start optimizing the python code and c code. 
- Organize and implement the c and python code in order to make the call via CMD with more functionalities and easier.
- Create pip package to encrypt and decrypt using ARADI.
- Create unit tests/module for testing inputs and outputs to verify the integrity of the encryption.
- Organize the port to other systems and benchmark speed.

Create Environment (/env folder will be ignored by .gitignore)

```python3 -m venv env```

Activate the environment:

```source env/bin/activate```

Make your changes and check if the pre-commit checks are available

```pre-commit install```
